kerneltest/e32test/benchmark/bm_ldd.cpp
changeset 200 73ea206103e6
parent 0 a41df078684a
--- a/kerneltest/e32test/benchmark/bm_ldd.cpp	Fri Jun 11 15:02:23 2010 +0300
+++ b/kerneltest/e32test/benchmark/bm_ldd.cpp	Wed Jun 23 19:44:53 2010 +0300
@@ -70,7 +70,7 @@
 	TInt StartTimerStampOverhead();
 	TInt RequestTimerStampOverhead();			// iRequestInterrupt() implementation
 
-	TInt SetAbsPrioirty(TInt aThreadHandle, TInt aNewPrio, TInt* aOldPrio);
+	TInt SetAbsPriority(TInt aThreadHandle, TInt aNewPrio, TInt* aOldPrio);
 
 	DMutex*			iLock;	// Shall be acquired by anyone who access the object's writable state.
 
@@ -533,9 +533,9 @@
 //
 
 //
 // The implmentation of RBMDriver::SetAbsPrioirty() call.
 //
-TInt DBMLChannel::SetAbsPrioirty(TInt aThreadHandle, TInt aNewPrio, TInt* aOldPrio)
+TInt DBMLChannel::SetAbsPriority(TInt aThreadHandle, TInt aNewPrio, TInt* aOldPrio)
 	{
 	NKern::LockSystem();
 	//
@@ -690,7 +690,7 @@
 			TInt newPrio;
 			TInt oldPrio;
 			umemget(&newPrio, a2, sizeof(newPrio));
-			r = SetAbsPrioirty((TInt) a1, newPrio, &oldPrio);
+			r = SetAbsPriority((TInt) a1, newPrio, &oldPrio);
 			umemput(a2, &oldPrio, sizeof(oldPrio));
 			break;
 			}
@@ -533,9 +533,9 @@
 
 //
-// The implmentation of RBMDriver::SetAbsPrioirty() call.
+// The implementation of RBMDriver::SetAbsPriority() call.
 //